@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Version: 1.2
+;; Version: 1.3
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -534,7 +534,7 @@ If CHECK is non-nil, always check first."
 (defun jinx--get-org-language ()
   "Get language from Org #+language keyword."
   (when (and (not (local-variable-p 'jinx-languages))
-             (derived-mode-p #'org-mode))
+             (derived-mode-p 'org-mode))
     (save-excursion
       (save-match-data
         (goto-char (point-min))
@@ -622,7 +622,7 @@ If CHECK is non-nil, always check first."
     (goto-char (overlay-end overlay))
     (unwind-protect
         (progn
-          (if (and (derived-mode-p #'org-mode)
+          (if (and (derived-mode-p 'org-mode)
                    (fboundp 'org-fold-show-set-visibility)
                    (fboundp 'org-fold-core-get-regions)
                    (fboundp 'org-fold-core-region))
@@ -1034,7 +1034,7 @@ This command dispatches to the following commands:
    (jinx-mode
     (jinx--load-module)
     (let ((enable-local-variables :safe))
-      (hack-local-variables))
+      (hack-local-variables 'ignore-mode))
     (jinx--get-org-language)
     (setq jinx--exclude-regexp
           (when-let ((regexps (jinx--mode-list jinx-exclude-regexps)))
